@@ -2,11 +2,7 @@ import random
 import cv2
 import numpy as np
 
-class AugmentationResult():
-  def __init__(self, augmentation, result, metadata=None):
-    self.augmentation = augmentation
-    self.result = result
-    self.metadata = metadata
+from Augraphy.Augmentations import AugmentationResult
 
 class AugraphyPipeline:
   def __init__(self, ink_phase, paper_phase, post_phase, ink_color_range=(0, 96), paper_color_range=(164, 255), rotate_range=(0,360)):
